@@ -40,7 +40,7 @@
 extern int main_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 25 "cfg-grammar.y" /* yacc.c:1909  */
+#line 25 "/syslog-ng-ose/syslog-ng/lib/cfg-grammar.y" /* yacc.c:1909  */
 
 
 /* this block is inserted into cfg-grammar.h, so it is included
@@ -48,6 +48,7 @@ extern int main_debug;
    with care. If you need additional headers, please look for a
    massive list of includes further below. */
 
+#pragma GCC diagnostic ignored "-Wswitch-default"
 /* YYSTYPE and YYLTYPE is defined by the lexer */
 #include "cfg-lexer.h"
 #include "afinter.h"
@@ -67,6 +68,7 @@ extern int main_debug;
 extern struct _LogSourceOptions *last_source_options;
 extern struct _LogReaderOptions *last_reader_options;
 extern struct _LogProtoServerOptions *last_proto_server_options;
+extern struct _LogProtoClientOptions *last_proto_client_options;
 extern struct _LogWriterOptions *last_writer_options;
 extern struct _FilePermOptions *last_file_perm_options;
 extern struct _MsgFormatOptions *last_msg_format_options;
@@ -81,7 +83,7 @@ extern struct _HostResolveOptions *last_host_resolve_options;
 extern struct _StatsOptions *last_stats_options;
 
 
-#line 85 "lib/cfg-grammar.h" /* yacc.c:1909  */
+#line 87 "lib/cfg-grammar.h" /* yacc.c:1909  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -117,8 +119,11 @@ extern struct _StatsOptions *last_stats_options;
     KW_BLOCK = 10007,
     KW_JUNCTION = 10008,
     KW_CHANNEL = 10009,
-    KW_INTERNAL = 10010,
-    KW_FILE = 10011,
+    KW_IF = 10010,
+    KW_ELSE = 10011,
+    KW_ELIF = 10012,
+    KW_INTERNAL = 10020,
+    KW_FILE = 10021,
     KW_SYSLOG = 10060,
     KW_MARK_FREQ = 10071,
     KW_STATS_FREQ = 10072,
@@ -257,8 +262,11 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_BLOCK 10007
 #define KW_JUNCTION 10008
 #define KW_CHANNEL 10009
-#define KW_INTERNAL 10010
-#define KW_FILE 10011
+#define KW_IF 10010
+#define KW_ELSE 10011
+#define KW_ELIF 10012
+#define KW_INTERNAL 10020
+#define KW_FILE 10021
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
 #define KW_STATS_FREQ 10072
